ngsLCA_barplot: Generate Taxa Abundance Barplots

View source: R/ngsLCA_barplot.R

ngsLCA_barplotR Documentation

Generate Taxa Abundance Barplots

Description

Generate barplots for taxa profiles into "path/run/barplot/" to show the reads abundance.

Usage

ngsLCA_barplot(path, run = "run01", taxa.number = 10)

Arguments

path

working directory, same to ngsLCA_profile.

run

name of the run, default is "run01".

taxa.number

maximum number of taxa will be shown in barplots; default is 10.

Value

Taxa abundance barplots.

Examples

ngsLCA_barplot(path=system.file("extdata","lca_files",package="ngsLCA"),
               run="run01",
               taxa.number=10)


## This will generate barplots for the complete taxa profile
## as well as taxa groups and ranks (if available) of "run01"
## in "path/run01/barplot/", with showing the 10 most abundant
## taxa in each profile.



wyc661217/ngsLCA documentation built on June 2, 2025, 12:02 a.m.