View source: R/ngsLCA_barplot.R
| ngsLCA_barplot | R Documentation |
Generate barplots for taxa profiles into "path/run/barplot/" to show the reads abundance.
ngsLCA_barplot(path, run = "run01", taxa.number = 10)
path |
working directory, same to |
run |
name of the run, default is "run01". |
taxa.number |
maximum number of taxa will be shown in barplots; default is 10. |
Taxa abundance barplots.
ngsLCA_barplot(path=system.file("extdata","lca_files",package="ngsLCA"),
run="run01",
taxa.number=10)
## This will generate barplots for the complete taxa profile
## as well as taxa groups and ranks (if available) of "run01"
## in "path/run01/barplot/", with showing the 10 most abundant
## taxa in each profile.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.